
```scala
package ohnosequences.mg7.loquats

import ohnosequences.mg7._
import ohnosequences.loquat._
import ohnosequences.statika._
import ohnosequences.cosas._, types._, klists._
import ohnosequences.datasets._
import ohnosequences.fastarious._, fasta._

import better.files._
import collection.JavaConversions._


case class splitDataProcessing(params: AnyMG7Parameters) extends DataProcessingBundle()(
  input = data.splitInput,
  output = data.splitOutput
) {

  def instructions: AnyInstructions = say("Splitting, cutting, separating")

  def process(context: ProcessingContext[Input]): AnyInstructions { type Out <: OutputFiles } = {

    val outputDir = context / "chunks"

    LazyTry {
      outputDir.createDirectories()

      val lines: Iterator[String] = context.inputFile(data.mergedReads).lines

      val fastasIterator: Iterator[String] = params.splitInputFormat match {
        // if input is FastQ, we parse it, convert it to FASTA and get String version
        case FastQInput => fastq.parseFastqDropErrors(lines).map(_.toFASTA.asString)
        // if it's Fasta, we parse it and get String version
        case FastaInput => fasta.parseFastaDropErrors(lines).map(_.asString)
      }

      // group it
      fastasIterator
        .grouped(params.splitChunkSize)
        .zipWithIndex
        .foreach { case (chunk, n) =>

          (outputDir / s"chunk.${n}.fasta")
            .overwrite(chunk.mkString("\n"))
        }
    } -&-
    success("chunk-chunk-chunk!",
      data.fastaChunks(outputDir) ::
      *[AnyDenotation { type Value <: FileResource }]
    )

  }
}

```




[main/scala/mg7/bio4j/bundle.scala]: ../bio4j/bundle.scala.md
[main/scala/mg7/bio4j/taxonomyTree.scala]: ../bio4j/taxonomyTree.scala.md
[main/scala/mg7/bio4j/titanTaxonomyTree.scala]: ../bio4j/titanTaxonomyTree.scala.md
[main/scala/mg7/csv.scala]: ../csv.scala.md
[main/scala/mg7/data.scala]: ../data.scala.md
[main/scala/mg7/dataflow.scala]: ../dataflow.scala.md
[main/scala/mg7/dataflows/full.scala]: ../dataflows/full.scala.md
[main/scala/mg7/dataflows/noFlash.scala]: ../dataflows/noFlash.scala.md
[main/scala/mg7/loquats/1.flash.scala]: 1.flash.scala.md
[main/scala/mg7/loquats/2.split.scala]: 2.split.scala.md
[main/scala/mg7/loquats/3.blast.scala]: 3.blast.scala.md
[main/scala/mg7/loquats/4.assign.scala]: 4.assign.scala.md
[main/scala/mg7/loquats/5.merge.scala]: 5.merge.scala.md
[main/scala/mg7/loquats/6.count.scala]: 6.count.scala.md
[main/scala/mg7/loquats/7.stats.scala]: 7.stats.scala.md
[main/scala/mg7/loquats/8.summary.scala]: 8.summary.scala.md
[main/scala/mg7/package.scala]: ../package.scala.md
[main/scala/mg7/parameters.scala]: ../parameters.scala.md
[main/scala/mg7/referenceDB.scala]: ../referenceDB.scala.md
[test/scala/mg7/counts.scala]: ../../../../test/scala/mg7/counts.scala.md
[test/scala/mg7/lca.scala]: ../../../../test/scala/mg7/lca.scala.md
[test/scala/mg7/pipeline.scala]: ../../../../test/scala/mg7/pipeline.scala.md
[test/scala/mg7/taxonomy.scala]: ../../../../test/scala/mg7/taxonomy.scala.md