
```scala
package ohnosequences.mg7.loquats

import ohnosequences.mg7._

import ohnosequences.loquat._

import ohnosequences.statika._

import ohnosequences.cosas._, types._, klists._

import ohnosequences.datasets._

import better.files._


case object mergeDataProcessing extends DataProcessingBundle()(
  input = data.mergeInput,
  output = data.mergeOutput
) {

  def instructions: AnyInstructions = say("Merging, joining, amalgamating!")


  // TODO: use streams, file-writers, etc. stuff
  def mergeChunks(dir: File, out: File, header: Option[String] = None): Unit = {
    header.foreach { out.appendLine }
    // only one level in depth:
    dir.list foreach { chunkFile =>
      out.append( chunkFile.contentAsString )
      chunkFile.delete()
    }
  }


  def process(context: ProcessingContext[Input]): AnyInstructions { type Out <: OutputFiles } = {

    val blastMerged  = (context / "blast.csv").createIfNotExists()
    val noHitsMerged = (context / "blast.no-hits").createIfNotExists()
    val lcaMerged    = (context / "lca.csv").createIfNotExists()
    val bbhMerged    = (context / "bbh.csv").createIfNotExists()

    // TODO: write header for Blast output
    LazyTry { mergeChunks( context.inputFile(data.blastChunksFolder), blastMerged)  } -&-
    LazyTry { mergeChunks( context.inputFile(data.blastNoHitsFolder), noHitsMerged) } -&-
    LazyTry { mergeChunks( context.inputFile(data.lcaChunksFolder), lcaMerged, Some(csv.assignHeader.mkString(",")) ) } -&-
    LazyTry { mergeChunks( context.inputFile(data.bbhChunksFolder), bbhMerged, Some(csv.assignHeader.mkString(",")) ) } -&-
    success(s"Everything is merged",
      data.blastResult(blastMerged) ::
      data.blastNoHits(noHitsMerged) ::
      data.lcaCSV(lcaMerged) ::
      data.bbhCSV(bbhMerged) ::
      *[AnyDenotation { type Value <: FileResource }]
    )

  }
}

```




[main/scala/mg7/bio4j/bundle.scala]: ../bio4j/bundle.scala.md
[main/scala/mg7/bio4j/taxonomyTree.scala]: ../bio4j/taxonomyTree.scala.md
[main/scala/mg7/bio4j/titanTaxonomyTree.scala]: ../bio4j/titanTaxonomyTree.scala.md
[main/scala/mg7/csv.scala]: ../csv.scala.md
[main/scala/mg7/data.scala]: ../data.scala.md
[main/scala/mg7/dataflow.scala]: ../dataflow.scala.md
[main/scala/mg7/dataflows/full.scala]: ../dataflows/full.scala.md
[main/scala/mg7/dataflows/noFlash.scala]: ../dataflows/noFlash.scala.md
[main/scala/mg7/loquats/1.flash.scala]: 1.flash.scala.md
[main/scala/mg7/loquats/2.split.scala]: 2.split.scala.md
[main/scala/mg7/loquats/3.blast.scala]: 3.blast.scala.md
[main/scala/mg7/loquats/4.assign.scala]: 4.assign.scala.md
[main/scala/mg7/loquats/5.merge.scala]: 5.merge.scala.md
[main/scala/mg7/loquats/6.count.scala]: 6.count.scala.md
[main/scala/mg7/loquats/7.stats.scala]: 7.stats.scala.md
[main/scala/mg7/loquats/8.summary.scala]: 8.summary.scala.md
[main/scala/mg7/package.scala]: ../package.scala.md
[main/scala/mg7/parameters.scala]: ../parameters.scala.md
[main/scala/mg7/referenceDB.scala]: ../referenceDB.scala.md
[test/scala/mg7/counts.scala]: ../../../../test/scala/mg7/counts.scala.md
[test/scala/mg7/lca.scala]: ../../../../test/scala/mg7/lca.scala.md
[test/scala/mg7/pipeline.scala]: ../../../../test/scala/mg7/pipeline.scala.md
[test/scala/mg7/taxonomy.scala]: ../../../../test/scala/mg7/taxonomy.scala.md