
```scala
package ohnosequences.mg7.loquats

import ohnosequences.mg7._

import ohnosequences.mg7.bio4j._, taxonomyTree._, titanTaxonomyTree._

import ohnosequences.loquat._

import ohnosequences.statika._
import ohnosequences.cosas._, types._, klists._
import ohnosequences.datasets._
import ohnosequences.fastarious._, fasta._

import better.files._
import com.github.tototoshi.csv._

import com.bio4j.titan.model.ncbiTaxonomy.TitanNCBITaxonomyGraph


case object summaryDataProcessing extends DataProcessingBundle()(
  input = data.summaryInput,
  output = data.summaryOutput
) {

  def countReads(file: File): Integer = {
    val source = io.Source.fromFile( file.toJava )
    val readsNumber = fasta.parseMap( source.getLines ).length
    source.close()
    readsNumber
  }

  def countLines(file: File): Integer = { file.lines.length }


  def instructions: ohnosequences.statika.AnyInstructions = say("Running summary loquat")

  def process(context: ProcessingContext[Input]): AnyInstructions { type Out <: OutputFiles } = {

    val summaryCSV: File = (context / "output" / "summary.csv").createIfNotExists()

    LazyTry {
      val csvWriter = csv.newWriter(summaryCSV)
      csvWriter.writeRow(csv.statsHeader)

      // only one level in depth:
      context.inputFile(data.sampleStatsFolder).list foreach { sampleStats =>

        // an ugly way to drop the header
        val row = csv.newReader(sampleStats).iterator.drop(1).next()
        csvWriter.writeRow(row)
      }

      csvWriter.close()
    } -&-
    success(s"Summary stats are ready",
      data.summaryStatsCSV(summaryCSV) ::
      *[AnyDenotation { type Value <: FileResource }]
    )
  }

}

```




[main/scala/mg7/bio4j/bundle.scala]: ../bio4j/bundle.scala.md
[main/scala/mg7/bio4j/taxonomyTree.scala]: ../bio4j/taxonomyTree.scala.md
[main/scala/mg7/bio4j/titanTaxonomyTree.scala]: ../bio4j/titanTaxonomyTree.scala.md
[main/scala/mg7/csv.scala]: ../csv.scala.md
[main/scala/mg7/data.scala]: ../data.scala.md
[main/scala/mg7/dataflow.scala]: ../dataflow.scala.md
[main/scala/mg7/dataflows/full.scala]: ../dataflows/full.scala.md
[main/scala/mg7/dataflows/noFlash.scala]: ../dataflows/noFlash.scala.md
[main/scala/mg7/loquats/1.flash.scala]: 1.flash.scala.md
[main/scala/mg7/loquats/2.split.scala]: 2.split.scala.md
[main/scala/mg7/loquats/3.blast.scala]: 3.blast.scala.md
[main/scala/mg7/loquats/4.assign.scala]: 4.assign.scala.md
[main/scala/mg7/loquats/5.merge.scala]: 5.merge.scala.md
[main/scala/mg7/loquats/6.count.scala]: 6.count.scala.md
[main/scala/mg7/loquats/7.stats.scala]: 7.stats.scala.md
[main/scala/mg7/loquats/8.summary.scala]: 8.summary.scala.md
[main/scala/mg7/package.scala]: ../package.scala.md
[main/scala/mg7/parameters.scala]: ../parameters.scala.md
[main/scala/mg7/referenceDB.scala]: ../referenceDB.scala.md
[test/scala/mg7/counts.scala]: ../../../../test/scala/mg7/counts.scala.md
[test/scala/mg7/lca.scala]: ../../../../test/scala/mg7/lca.scala.md
[test/scala/mg7/pipeline.scala]: ../../../../test/scala/mg7/pipeline.scala.md
[test/scala/mg7/taxonomy.scala]: ../../../../test/scala/mg7/taxonomy.scala.md